<template>
  <div class="container">
    <h1 class="fs-3 fl-4">Reset Password</h1>
    <p class="fl-5">
      <p>Password reset link will be sent to below email address.</p>
      <div class="mt-8">
        <form class="bg-grey-lighten-3 rounded-2 px-4 py-2 my-7 col-md-9 col-lg-7 col-xxl-6">
          <bs-input name="email" v-model="email" label="Email Address" type="text" placeholder="Enter email connected to your account"></bs-input>
        </form>

        <div class="col-md-9 col-lg-7 col-xxl-6 actions">
          <button class="mr-4 btn btn-primary" type="button" @click="resetPassword" :disabled="state.$waiting">
            <span v-if="state.$waiting" class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Send Password Reset Email</button>
          <button class="btn btn-secondary" type="button" @click="cancel">Cancel</button>
        </div>
      </div>
    </p>
  </div>
</template>

<script setup>
import BsInput from "/atila-vue/components/bs-input.vue"

const { state } = useStore ()
const email = ref ('')

function cancel () {
  router.back ()
}

async function resetPassword () {
  const validators = {email: frontend.validator.email}
  if (frontend.validator.failed ({email: email.value}, validators)) {
    return
  }

  state.$waiting = true
  if (!email.value.endsWith ('@kracknet.com')) {
    try {
      const auth = await firebase.getAuth ()
      await firebase.auth.sendPasswordResetEmail (auth, email.value)
    } catch (error) {
      return frontend.handle_firebase_error (error, "Reset Password")
    }
  }
  state.$waiting = false
  bootstrap.toast ({title: "Success", text: "Password reset link has been sent. Check your mail box."})
  router.push ('/')
}

onActivated (() => {
  frontend.set_title ()
})

</script>

<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.unauthentification_required ({path: '/'}, {to, from, next})
  }
}
</script>
